@@ -2,16 +2,18 @@ import copy
 import betamax
 import github3
 import os
+import pytest
 import unittest
 
 
+@pytest.mark.usefixtures('betamax_simple_body')
 class IntegrationHelper(unittest.TestCase):
     def setUp(self):
         self.user = os.environ.get('GH_USER', 'foo')
         self.password = os.environ.get('GH_PASSWORD', 'bar')
         self.token = os.environ.get('GH_AUTH', 'x' * 20)
         self.gh = self.get_client()
-        self.session = self.gh._session
+        self.session = self.gh.session
         self.recorder = betamax.Betamax(self.session)
 
     def get_client(self):
@@ -23,6 +25,14 @@ class IntegrationHelper(unittest.TestCase):
     def basic_login(self):
         self.gh.login(self.user, self.password)
 
+    def auto_login(self):
+        """Log in appropriately based on discovered credentials"""
+
+        if self.token:
+            self.token_login()
+        else:
+            self.basic_login()
+
     def cassette_name(self, method, cls=None):
         class_name = cls or self.described_class
         return '_'.join([class_name, method])
@@ -44,7 +54,24 @@ class CustomHeadersMatcher(betamax.BaseMatcher):
         recorded_request = copy.deepcopy(recorded_request)
         request.headers.pop('User-Agent', None)
         recorded_request['headers'].pop('User-Agent', None)
+        request.headers.pop('Accept-Encoding', None)
+        recorded_request['headers'].pop('Accept-Encoding', None)
+        request.headers.pop('Connection', None)
+        recorded_request['headers'].pop('Connection', None)
         return self.headers_matcher.match(request, recorded_request)
 
 
 betamax.Betamax.register_request_matcher(CustomHeadersMatcher)
+
+
+@pytest.mark.usefixtures('enterprise_url')
+class GitHubEnterpriseHelper(IntegrationHelper):
+
+    def get_client(self):
+        return github3.GitHubEnterprise(self.enterprise_url)
+
+
+class GitHubStatusHelper(IntegrationHelper):
+
+    def get_client(self):
+        return github3.GitHubStatus()
